@@ -3,7 +3,7 @@
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : March 1996
 # STATUS  : Alpha
-# REVISION: $Id: HSP.pm,v 1.2.2.2 1999/02/05 18:56:27 sac Exp $
+# REVISION: $Id: HSP.pm,v 1.6 2000/03/22 09:41:11 sac Exp $
 #
 # For the latest version and documentation, visit the distribution site:
 #    http://genome-www.stanford.edu/perlOOP/bioperl/blast/
@@ -11,7 +11,7 @@
 # To generate documentation, run this module through pod2html
 # (preferably from Perl v5.004 or better).
 #
-# Copyright (c) 1996-98 Steve A. Chervitz. All Rights Reserved.
+# Copyright (c) 1996-2000 Steve A. Chervitz. All Rights Reserved.
 #           This module is free software; you can redistribute it and/or 
 #           modify it under the same terms as Perl itself.
 #----------------------------------------------------------------------------
@@ -25,14 +25,14 @@ use Bio::Root::Object ();
 @ISA = qw( Bio::Root::Object);  
 
 use strict;
-use vars qw($ID $VERSION $GAP_SYMBOL @SCORE_CUTOFFS $Revision);
+use vars qw($ID $VERSION $GAP_SYMBOL @SCORE_CUTOFFS $Revision %STRAND_SYMBOL);
 $ID       = 'Bio::Tools::Blast::HSP';
-$VERSION  = 0.074;
-$Revision = '$Id: HSP.pm,v 1.2.2.2 1999/02/05 18:56:27 sac Exp $';  #'
+$VERSION  = 0.09;
+$Revision = '$Id: HSP.pm,v 1.6 2000/03/22 09:41:11 sac Exp $';  #'
 
 $GAP_SYMBOL    = '-';          # Need a more general way to handle gap symbols.
 @SCORE_CUTOFFS = ( 100, 30 );  # Bit score cutoffs (see homol_score()).
-
+%STRAND_SYMBOL = ('Plus' => 1, 'Minus' => -1);
 
 ## POD Documentation:
 
@@ -53,7 +53,6 @@ for a description of constructor parameters.
     $hspObj = eval{ new Bio::Tools::Blast::HSP(-DATA    =>\@hspData, 
 					       -PARENT  =>$sbjct_object, 
 					       -NAME    =>$hspCount,
-					       -GAPPED  =>1,
  		                               -PROGRAM =>'TBLASTN',
 					       );
 		};
@@ -138,7 +137,7 @@ Steve A. Chervitz, sac@genome.stanford.edu
 
 =head1 VERSION
 
-Bio::Tools::Blast::HSP.pm, 0.074
+Bio::Tools::Blast::HSP.pm, 0.09
 
 =head1 SEE ALSO
 
@@ -202,7 +201,6 @@ for documentation purposes only.
            :      -DATA    => array ref containing raw data for one HSP.
            :      -PARENT  => Sbjct.pm object ref.
            :      -NAME    => integer (1..n).
-           :      -GAPPED  => boolean (gapped alignments?).
            :      -PROGRAM => string ('TBLASTN', 'BLASTP', etc.).
 
 See Also   : L<_set_data>(), B<Bio::Root::Object::new()>, B<Bio::Tools::Blast::Sbjct::_set_hsps()>
@@ -218,7 +216,7 @@ sub _initialize {
 
     # The gapped and program booleans may be needed after the HSP object
     # is built.
-    $self->{'_gapped'} = $param{-GAPPED} || 0;
+#    $self->{'_gapped'} = $param{-GAPPED} || 0;
     $self->{'_prog'} = $param{-PROGRAM} || 0;  
     $self->_set_data( @{$param{-DATA}} );
 }
@@ -271,7 +269,7 @@ sub _set_data {
 
 	if( $line =~ /^ ?Score/ ) {
 	    $self->_set_score_stats( $line );
-	} elsif( $line =~ /^ ?Identities/ ) {
+	} elsif( $line =~ /^ ?(Identities|Positives|Strand)/ ) {
 	    $self->_set_match_stats( $line );
 	} elsif( $line =~ /^ ?Frame = ([\d+-]+)/ ) {
 	    # Version 2.0.8 has Frame information on a separate line.
@@ -300,6 +298,11 @@ sub _set_data {
     # Storing the match list in case it is needed later.
     $self->{'_matchList'} = \@matchList;
 
+    if(not defined ($self->{'_numIdentical'})) {
+      $self->throw("Can't parse match statistics.",
+		   "Possibly a new or unrecognized Blast format.");
+    }
+
     if(!scalar @queryList or !scalar @sbjctList) {
         $self->throw("Can't find query or sbjct alignment lines.",
 	  	     "Possibly unrecognized Blast format.");
@@ -331,26 +334,26 @@ sub _set_score_stats {
 
     my ($expect, $p);
 
-    if($data =~ /Score = +([\d.e+]+) bits \(([\d.e+]+)\), +Expect = +([\d.e+-]+)/) {
+    if($data =~ /Score = +([\d.e+-]+) bits \(([\d.e+-]+)\), +Expect = +([\d.e+-]+)/) {
 	# blast2 format n = 1
 	$self->{'_bits'}   = $1;
 	$self->{'_score'}  = $2;
 	$expect            = $3;
-    } elsif($data =~ /Score = +([\d.e+]+) bits \(([\d.e+]+)\), +Expect\((\d+)\) = +([\d.e+-]+)/) {
+    } elsif($data =~ /Score = +([\d.e+-]+) bits \(([\d.e+-]+)\), +Expect\((\d+)\) = +([\d.e+-]+)/) {
 	# blast2 format n > 1
 	$self->{'_bits'}   = $1;
 	$self->{'_score'}  = $2;
 	$self->{'_n'}      = $3;
 	$expect            = $4;
 
-    } elsif($data =~ /Score = +([\d.e+]+) \(([\d.e+]+) bits\), +Expect = +([\d.e+-]+), P = +([\d.e-]+)/) {
+    } elsif($data =~ /Score = +([\d.e+-]+) \(([\d.e+-]+) bits\), +Expect = +([\d.e+-]+), P = +([\d.e-]+)/) {
 	# blast1 format, n = 1
 	$self->{'_score'}  = $1;
 	$self->{'_bits'}   = $2;
 	$expect            = $3;
 	$p                 = $4;
 
-    } elsif($data =~ /Score = +([\d.e+]+) \(([\d.e+]+) bits\), +Expect = +([\d.e+-]+), +Sum P\((\d+)\) = +([\d.e-]+)/) {
+    } elsif($data =~ /Score = +([\d.e+-]+) \(([\d.e+-]+) bits\), +Expect = +([\d.e+-]+), +Sum P\((\d+)\) = +([\d.e-]+)/) {
 	# blast1 format, n > 1
 	$self->{'_score'}  = $1;
 	$self->{'_bits'}   = $2;
@@ -399,17 +402,21 @@ sub _set_match_stats {
 #--------------------
     my ($self, $data) = @_;
 
-    if($data =~ m!Identities = (\d+)/(\d+).+?, Positives = (\d+)/(\d+)!) {
-	# blast1 or 2 format
-	$self->{'_numIdentical'} = $1;
-	$self->{'_totalLength'}  = $2;
-	$self->{'_numConserved'} = $3;
-
-    } else {
-	$self->throw("Can't parse match statistics: unrecognized format.", "$data");
+    if($data =~ m!Identities = (\d+)/(\d+)!) {
+      # blast1 or 2 format
+      $self->{'_numIdentical'} = $1;
+      $self->{'_totalLength'}  = $2;
+    }
+    
+    if($data =~ m!Positives = (\d+)/(\d+)!) {
+      # blast1 or 2 format
+      $self->{'_numConserved'} = $1;
+      $self->{'_totalLength'}  = $2;
+    }
+    
+    if($data =~ m!Frame = ([\d+-]+)!) { 
+      $self->{'_frame'} = $1; 
     }
-
-    if($data =~ m!Frame = ([\d+-]+)!) { $self->{'_frame'} = $1; }
 
     # Strand data is not always present in this line.
     # _set_seq() will also set strand information.
@@ -534,11 +541,12 @@ sub _set_seq {
     } 
 
     ## Count number of gaps in each seq. Only need to do this for gapped Blasts.
-    if($self->{'_gapped'}) {
+#    if($self->{'_gapped'}) {
 	my $seqstr = join('', @sequence);
 	$seqstr =~ s/\s//g;
-	$self->{$seqType.'Gaps'} = CORE::length($seqstr) - $self->{$seqType.'Length'};
-    }
+        my $num_gaps = CORE::length($seqstr) - $self->{$seqType.'Length'};
+	$self->{$seqType.'Gaps'} = $num_gaps if $num_gaps > 0;
+#    }
 }
 
 
@@ -880,11 +888,11 @@ sub gaps {
     $seqType  ||= (wantarray ? 'list' : 'total');
 
     if($seqType =~ /list|array/i) {
-	return ($self->{'_queryGaps'}, $self->{'_sbjctGaps'});
+	return (($self->{'_queryGaps'} || 0), ($self->{'_sbjctGaps'} || 0));
     }
 
     if($seqType eq 'total') {
-	return $self->{'_queryGaps'} + $self->{'_sbjctGaps'};
+	return ($self->{'_queryGaps'} + $self->{'_sbjctGaps'}) || 0;
     } else {
 	## Sensitive to member name format.
 	$seqType = "_\L$seqType\E";
@@ -954,7 +962,8 @@ sub matches {
 
 	} elsif (($self->{'_prog'} eq 'BLASTX') and ($seqType eq 'query'))
 	{
-	    ## ML: does BLASTX also need special handling?
+	    $seq = substr($self->seq_str('match'),
+			  int(($beg-$start)/3), int(($end-$beg+1)/3));
 	} else {
 	    $seq = substr($self->seq_str('match'), 
 			  $beg-$start, ($end-$beg));
@@ -1247,13 +1256,14 @@ sub end {
  Purpose   : Get the strand of the query or sbjct sequence.
  Example   : print $hsp->strand('query');
            : ($qstrand, $sstrand) = $hsp->strand();
- Returns   : string: 'Minus' or 'Plus'
-           : In scalar context without arguments, returns queryStrand.
+ Returns   : -1, 0, or 1
+           : -1 = Minus strand, +1 = Plus strand
+           : Returns 0 if strand is not defined, which occurs
+           : for non-TBLASTN/X reports.
+           : In scalar context without arguments, returns queryStrand value.
            : In array context without arguments, returns a two-element list 
            :    of strings (queryStrand, sbjctStrand).
            : Array context can be "induced" by providing an argument of 'list' or 'array'.
-           : Returns null string(s) if strand is not defined, which occurs
-           : for non-TBLASTN/X reports.
  Argument  : seq_type: 'query' | 'sbjct' or undef
  Throws    : n/a
 
@@ -1279,7 +1289,8 @@ sub strand {
 	return ('','') unless defined $self->{'_queryStrand'};
 	return ($self->{'_queryStrand'}, $self->{'_sbjctStrand'});
     }
-    $self->{$seqType.'Strand'} || '';
+    local $^W = 0;
+    $STRAND_SYMBOL{$self->{$seqType.'Strand'}} || 0;
 }
 
 
