@@ -11,7 +11,7 @@
 #                 support.
 # CREATED : 4 May 1998
 # STATUS  : Alpha
-# REVISION: $Id: Webblast.pm,v 1.4.2.5 1999/06/27 07:41:36 sac Exp $
+# REVISION: $Id: Webblast.pm,v 1.7.2.3 2000/05/15 08:34:35 sac Exp $
 #
 # For documentation, run this module through pod2html
 # (preferably from Perl v5.004 or better).
@@ -25,6 +25,7 @@
 #------------------------------------------------------------------------
 
 package Bio::Tools::Blast::Run::Webblast;
+use strict;
 
 # rnc: now uses HTTP and LWP.
 # sac: Make sure HTTP and LWP are available.
@@ -33,7 +34,7 @@ package Bio::Tools::Blast::Run::Webblast;
 #      still be examined. Dieing only if blast_remote() is attempted.
 
 BEGIN {
-  use vars qw($Loaded_LWP);
+  use vars qw($Loaded_LWP $Loaded_IOScalar);
   $Loaded_LWP = 1;
   unless( eval "require HTTP::Request::Common" and
 	  eval "require LWP::UserAgent") {
@@ -46,13 +47,28 @@ BEGIN {
   }
 
   HTTP::Request::Common->import(qw(POST)) if $Loaded_LWP;
+
+  $Loaded_IOScalar = 1;
+  unless( eval "require IO::Scalar") {
+    warn "\a\n".'='x50, "\n".
+      "WARNING: COULDN'T LOAD THE IO::Scalar MODULE.\n\n".
+      "   IO::Scalar is now required to run remote Blasts.\n".
+      "   This module is included in the IO-stringy collection\n".
+      "   from CPAN: http://www.perl.com/CPAN/.".
+	"\n".'='x50, "\n\n";
+    $Loaded_IOScalar = 0;
+  }
 }
 
+use Bio::SeqIO;
 use Bio::Root::Global    qw(:devel);
 use Bio::Root::Utilities qw(:obj);
 use Bio::Tools::Blast::HTML qw(&strip_html);
+use IO::Scalar;
 use Carp;
 
+use Exporter;
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA        = qw(Exporter);
 @EXPORT     = qw();
 @EXPORT_OK  = qw(&blast_remote @Blast_dbp_remote @Blast_dbn_remote 
@@ -64,7 +80,7 @@ use strict;
 use vars qw( $ID $VERSION $revision);
 
 $ID       = 'Bio::Tools::Blast::Run::Webblast';
-$VERSION  = 1.22; 
+$VERSION  = 1.24; 
 
 # SAC: grouped database names.
 # May want to put these sorts of things in a
@@ -101,9 +117,11 @@ my %_default = (
 		'minimumLengthProtein'  => 10,
 		'maximumLength'         => 100000, 
 		'maximumLengthProtein'  => 50000, 
-		'blastServerURL1'       => 'www.ncbi.nlm.nih.gov/cgi-bin/BLAST/nph-blast',
-		'blastServerURL2'       => 'www.ncbi.nlm.nih.gov/cgi-bin/BLAST/nph-newblast',
-		'blastServerURLpsi'     => 'www.ncbi.nlm.nih.gov/cgi-bin/BLAST/nph-psi_blast',
+# Blast1 no longer supported at NCBI
+#		'blastServerURL1'       => 'www.ncbi.nlm.nih.gov/',
+		'blastServerURL2'       => 'www.ncbi.nlm.nih.gov/blast/blast.cgi',
+		'blastServerURLpsi'     => 'www.ncbi.nlm.nih.gov/blast/psiblast.cgi',
+		'blastServerURLphi'     => 'www.ncbi.nlm.nih.gov/blast/phiblast.cgi',
 		# rnc:	added WashU-Blast2 server address, ..WashU - first remote WashU Blast Server to use
 		# rnc:	added proxy server address option
 		'blastServerURLWashU'	=> 'www2.ebi.ac.uk/cgi-bin/newblast2.pl',
@@ -341,7 +359,7 @@ their resolution. Bug reports can be submitted via email or the web:
 
 =head1 VERSION
 
-Bio::Tools::Blast::Run::Webblast.pm, 1.22
+Bio::Tools::Blast::Run::Webblast.pm, 1.24
 
 =head1 COPYRIGHT
 
@@ -527,6 +545,13 @@ sub blast_remote {
 	     "   Download it from CPAN: http://www.perl.com/CPAN/.\n");
     }
 
+    unless ($Loaded_IOScalar) {
+      croak ("THE IO::Scalar MODULE IS NOT INSTALLED.\n\n".
+             "   IO::Scalar is now required to run remote Blasts.\n".
+             "   This module is included in the IO-stringy collection\n".
+             "   from CPAN: http://www.perl.com/CPAN/.");
+  }
+
     my ($seq_a);
     eval { 
 	# _rearrange() is an instance method of Bio::Root::Object.pm and is
@@ -796,7 +821,11 @@ sub _blast {
 	    next unless &_validate_seq($seq);
 	    
 	    # add >seq_name to make seq in fasta format
-	    $sequenceInFastaFormat= $seq->layout('Fasta');
+            my $sh = new_tie IO::Scalar \$sequenceInFastaFormat;
+            my $out = Bio::SeqIO->new ('-fh'   => $sh,   
+                                       '-format' =>'Fasta');
+
+            $out->write_seq($seq);
 	    $sequenceInFastaFormat =~ s/\n$//;
 	    
 	    # concatenate advanced options into a string, depending on differnt blast type
@@ -1112,7 +1141,11 @@ sub _blast {
 			      if(-s $outputFileNameTemp) 
 				{
 				    $outFile = $outputFileNameTemp;
-				    $MONITOR && print STDERR "Possibly bad Blast result saved to file $outputFileNameTemp\n"; 
+# Updated for the operation of the NCBI queueing system
+# which now always results in the temporary file being saved.
+				    $MONITOR && print STDERR "Blast submission result saved to file $outputFileNameTemp\n"; 
+# Formerly, when the actual report was returned:
+#				    $MONITOR && print STDERR "Possibly bad Blast result saved to file $outputFileNameTemp\n"; 
 				} else {
 				    unlink $outputFileNameTemp;
 				    $MONITOR && print STDERR "No Blast results saved.\n";
@@ -1197,8 +1230,8 @@ sub _validate_seq {
 # Returns : zero if sequence length is too short or too long
 #           otherwise returns 1.
     my $seq = shift;
-    my $type = $seq->type;
-    my $len = $seq->seq_len;
+    my $type = $seq->moltype;
+    my $len = $seq->length;
 
     # Verify that sequence type is correct type for selected program.
     if( (defined $type and $type !~ /unknown/i) 
@@ -1989,6 +2022,14 @@ __END__
 ############################################################################
 
 # MODIFICATION HISTORY :
+#  1.24, 15 May 2000 sac:
+#     -- Uses SeqIO and IO::Scalar instead of Bio::Seq->layout()
+#        to get a Fasta-formatted sequence string.
+#     -- Removed message about possibly bad blast report
+#        which now always happens given the NCBI queueing system
+#
+#  1.23, 15 Oct 1999, sac:
+#     -- Updated the URLs for the NCBI servers.
 #
 #  1.22, 26 Jun 1999, sac:
 #      -- Bug fix in _blast(): Removing characters from temp file name 
