@@ -4,42 +4,39 @@
 #           and eventually for parsing, analyzing, running Fasta analyses.
 # AUTHOR  : Steve A. Chervitz (sac@genome.stanford.edu)
 # CREATED : 27 Mar 1998
-# REVISION: $Id: Fasta.pm,v 1.1.1.1.2.1 1999/02/04 16:19:26 sac Exp $
+# REVISION: $Id: Fasta.pm,v 1.5 2000/03/15 11:23:20 jgrg Exp $
 # STATUS  : Alpha
 #
 # For documentation, run this module through pod2html 
 # (preferably from Perl v5.004 or better).
 #
-# MODIFIED:
-# sac --- Thu Feb  4 03:45:25 1999:
-#   * _parse_seq_stream() calls get_newline_char() to autoconfigure the
-#    record searator for different platforms.
-# sac --- Mon Sep  7 13:20:48 1998:
-#   * Modified _get_parse_seq_func() to destroy all created Seq objects
-#      after calling exec_func if an exec_func supplied.
-#      (A similar thing is done in Bio::Tools::Blast::_get_parse_func().)
+# MODIFICATION NOTES:  See bottom of file.
 #
-# sac --- Sun Jun 14 23:23:43 1998:
-#   * Minor changes.
 #-------------------------------------------------------------------------------
 
 package Bio::Tools::Fasta;
+use strict;
+
+BEGIN {
+   warn "Deprecation Warning: $0 uses Bio::Tools::Fasta.pm.\n" .
+        "This module has been deprecated. Use the Bio::SeqIO system instead.\n\n";
+}
 
 use Bio::Tools::SeqAnal;
 use Bio::Root::Global     qw(:std);
 use Bio::Root::Utilities  qw(:obj); 
 
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS
+            $ID $VERSION $Fasta $RawData $Newline);
+
 @ISA        = qw( Bio::Tools::SeqAnal Exporter);
 @EXPORT     = qw();
 @EXPORT_OK  = qw($VERSION $Fasta);
 %EXPORT_TAGS = ( obj => [qw($Fasta)],
 		 std => [qw($Fasta)]);
 
-use strict;
-use vars qw($ID $VERSION $Fasta $RawData $Newline_char);
-
 $ID = 'Bio::Tools::Fasta';
-$VERSION  = 0.012; 
+$VERSION  = 0.014; 
 
 
 ## Static FASTA object. 
@@ -168,7 +165,7 @@ Steve A. Chervitz, sac@genome.stanford.edu
 
 =head1 VERSION
 
-Bio::Tools::Fasta.pm, 0.012
+Bio::Tools::Fasta.pm, 0.014
 
 =head1 COPYRIGHT
 
@@ -392,9 +389,9 @@ sub _parse_seq_stream {
     $self->{'_seqCount'} = 0;
 
     # Only setting the newline character once for efficiency.
-    $Newline_char ||= $Util->get_newline_char(-client => $self, %param);
+    $Newline ||= $Util->get_newline(-client => $self, %param);
 
-    $self->read(-REC_SEP  =>"$Newline_char>", 
+    $self->read(-REC_SEP  =>"$Newline>", 
 		-FUNC     => $func,
 		%param);
 
@@ -676,7 +673,7 @@ sub _set_id_desc {
 =cut
 
 #------------
-sub num_seqs { my $self = shift;  $self->{'_num_seqs'}; }
+sub num_seqs { my $self = shift;  $self->{'_seqCount'}; }
 #------------
 
 
@@ -717,7 +714,7 @@ all or some of the following fields:
 
  FIELD           VALUE
  --------------------------------------------------------------
- _num_seqs       Number of sequences parsed.
+ _seqCount       Number of sequences parsed.
 
  _edit_seq       Boolean. Should sequences be edited during parsing?
 
@@ -733,5 +730,20 @@ all or some of the following fields:
 
 =cut
 
-1;
 
+MODIFICATION NOTES:
+-------------------
+0.014, steve --- Wed Feb 17 02:22:26 1999
+  * Fixed bug in num_seqs().
+
+0.013, sac --- Thu Feb  4 03:45:25 1999:
+  * _parse_seq_stream() calls get_newline() to autoconfigure the
+   record searator for different platforms.
+
+0.012, sac --- Mon Sep  7 13:20:48 1998:
+  * Modified _get_parse_seq_func() to destroy all created Seq objects
+     after calling exec_func if an exec_func supplied.
+     (A similar thing is done in Bio::Tools::Blast::_get_parse_func().)
+
+0.011, sac --- Sun Jun 14 23:23:43 1998:
+  * Minor changes.
